X-Git-Url: https://www.chiark.greenend.org.uk/ucgi/~mdw/git/disorder/blobdiff_plain/75d64210316e5f0e607eecf9abec4dea8151bb2c..477b12ff719d3749b8d8f85035bd6384fee9be0d:/lib/logfd.c
diff --git a/lib/logfd.c b/lib/logfd.c
index 60e5331..7175108 100644
--- a/lib/logfd.c
+++ b/lib/logfd.c
@@ -1,28 +1,27 @@
/*
* This file is part of DisOrder
- * Copyright (C) 2005 Richard Kettlewell
+ * Copyright (C) 2005, 2007 Richard Kettlewell
*
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
- *
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
* You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * along with this program. If not, see .
+ */
+/** @file lib/logfd.c
+ * @brief Redirect subprocess stderr to DisOrder server's log
*/
-#include
-#include "types.h"
+#include "common.h"
#include
-#include
#include
#include "syscalls.h"
@@ -30,7 +29,7 @@
#include "event.h"
#include "log.h"
-/* called when bytes are available and at eof */
+/** @brief Called when a log FD is readable */
static int logfd_readable(ev_source attribute((unused)) *ev,
ev_reader *reader,
void *ptr,
@@ -44,24 +43,24 @@ static int logfd_readable(ev_source attribute((unused)) *ev,
while((nl = memchr(ptr, '\n', bytes))) {
len = nl - (char *)ptr;
ev_reader_consume(reader, len + 1);
- info("%s: %.*s", tag, len, (char *)ptr);
+ disorder_info("%s: %.*s", tag, len, (char *)ptr);
ptr = nl + 1;
bytes -= len + 1;
}
if(eof && bytes) {
- info("%s: %.*s", tag, (int)bytes, (char *)ptr);
+ disorder_info("%s: %.*s", tag, (int)bytes, (char *)ptr);
ev_reader_consume(reader, bytes);
}
return 0;
}
-/* called when a read error occurs */
+/** @brief Called when a log FD errors */
static int logfd_error(ev_source attribute((unused)) *ev,
int errno_value,
void *u) {
const char *tag = u;
- error(errno_value, "error reading log pipe from %s", tag);
+ disorder_error(errno_value, "error reading log pipe from %s", tag);
return 0;
}
@@ -75,7 +74,7 @@ static int logfd_error(ev_source attribute((unused)) *ev,
* it in the parent).
*
* Any lines written to this fd (i.e. by the subprocess) will be logged via
* info(), with @p tag included.
*/
int logfd(ev_source *ev, const char *tag) {
int p[2];
@@ -85,7 +84,7 @@ int logfd(ev_source *ev, const char *tag) {
nonblock(p[0]);
if(!ev_reader_new(ev, p[0], logfd_readable, logfd_error, (void *)tag,
"logfd"))
- fatal(errno, "error calling ev_reader_new");
+ disorder_fatal(errno, "error calling ev_reader_new");
return p[1];
}
@@ -75,7 +74,7 @@ static int logfd_error(ev_source attribute((unused)) *ev,
*
* Any lines written to this fd (i.e. by the subprocess) will be logged via
- * info(), with @p tag included.
+ * disorder_info(), with @p tag included.
*/
int logfd(ev_source *ev, const char *tag) {